km3pipe.io.CHPump
=================

.. currentmodule:: km3pipe.io

.. autoclass:: CHPump

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~CHPump.__init__
      ~CHPump.add
      ~CHPump.close
      ~CHPump.close_file
      ~CHPump.configure
      ~CHPump.expose
      ~CHPump.finish
      ~CHPump.get
      ~CHPump.next
      ~CHPump.open_file
      ~CHPump.pre_finish
      ~CHPump.process
      ~CHPump.require
      ~CHPump.rewind_file
      ~CHPump.show_performance_statistics
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~CHPump.name
   
   